@@ -12,7 +12,7 @@ use vars qw(@EXPORT @ISA $DEFAULT_OPTIONS $PROGRAM_NAME $VERSION);
 @EXPORT = qw( process_options whence_file $DEFAULT_OPTIONS $PROGRAM_NAME $VERSION);
 
 BEGIN {
-    $PROGRAM_NAME = 'trepanpl';
+    $PROGRAM_NAME = 'trepan.pl';
     $VERSION      = '0.1.2';
 }
 use constant VERSION => $VERSION;
@@ -20,6 +20,13 @@ use constant PROGRAM_NAME => $PROGRAM_NAME;
 
 @ISA    = qw(Exporter);
 
+# Return whether we want Terminal highlighting by default
+sub default_term() {
+    ($ENV{'TERM'} && ($ENV{'TERM'} ne 'dumb' || 
+		     (exists($ENV{'EMACS'}) && $ENV{'EMACS'} eq 't')))
+	?  'term' : 0
+}
+
 my $home = $ENV{'HOME'} || glob("~");
 my $initfile = File::Spec->catfile($home, '.treplrc');
 $DEFAULT_OPTIONS = {
@@ -30,7 +37,9 @@ $DEFAULT_OPTIONS = {
     basename     => 0,
     nx           => 0,     # Don't run user startup file (e.g. .treplrc)
     cmdfiles     => [],
-    highlight    => 1,
+    client       => 0,     # Set 1 if we want to connect to an out-of
+                           # process debugger "server".
+    highlight    => default_term(),
     # Default values used only when 'server' or 'client'
     # (out-of-process debugging)
     port         => 1954,
@@ -40,7 +49,6 @@ $DEFAULT_OPTIONS = {
 
 };
 
-
 sub show_version()
 {
     printf "Trepan, version %s\n", VERSION;
@@ -63,11 +71,14 @@ sub process_options($)
 	 'host:s'       => \$opts->{host},
 	 'basename'     => \$opts->{basename},
 	 'batch:s'      => \$opts->{batchfile},
+	 'client'       => \$opts->{client},
+	 'server'       => \$opts->{server},
 	 'testing:s'    => \$opts->{testing},
 	 'c|command=s@' => \$opts->{cmdfiles},
 	 'cd:s'         => \$opts->{initial_dir},
 	 'nx'           => \$opts->{nx},
 	 'readline'     => \$opts->{readline},
+	 'no-readline' => sub { $opts->{readline} = 0},
 	 'x|trace'      => \$opts->{traceprint},
 	 'version'      => \$show_version,
 	);
@@ -88,6 +99,10 @@ sub process_options($)
 	}
 	$opts->{nx} = 1;
     }
+    if ($opts->{server} and $opts->{client}) {
+	printf STDERR 
+	    "Pick only on from of the --server or --client options\n";
+    }
     $opts;
 }
 
@@ -98,6 +113,8 @@ sub whence_file($)
     my $prog_script = shift;
 
     # If we have an relative or absolute file name, don't do anything.
+    return $prog_script if 
+	File::Spec->file_name_is_absolute($prog_script);
     my $first_char = substr($prog_script, 0, 1);
     return $prog_script if index('./', $first_char) != -1;
 
@@ -161,29 +178,40 @@ __END__
     
 =head1 TrepanPl
 
-trepanpl - Perl "Trepanning" Debugger 
+trepan.pl - Perl "Trepanning" Debugger 
 
 =head1 SYNOPSIS
 
    trepan [options] [[--] perl-program [perl-program-options ...]]
 
    Options:
-      --help              brief help message
-      --man               full documentation
-      --basename          Show basename only on source file listings. 
-                          (Needed in regression tests)
-      -c| --command FILE  Run debugger command file FILE
-      --batch FILE        Like --command, but quit after reading FILE.
-                          This option has precidence over --command and
-                          will also set --mx
-      --cd DIR            Change current directory to DIR
-      --nx                Don't run user startup file (e.g. .treplrc)
-      --port N            TCP/IP port to use on remote connection
-      --readline          Try to use Term::Readline
-      -x|--trace          Simulate line tracing (think POSIX shell set -x)
+      --help               brief help message
+      --man                full documentation
+      --basename           Show basename only on source file listings. 
+                           (Needed in regression tests)
+      
+      -c| --command FILE   Run debugger command file FILE
+      --batch FILE         Like --command, but quit after reading FILE.
+                           This option has precidence over --command and
+                           will also set --mx
+      --cd DIR             Change current directory to DIR
+      --nx                 Don't run user startup file (e.g. .treplrc)
+
+      --client | --server  Set for out-of-process debugging. The server 
+                           rus the Perl program to be debugged runs. 
+                           The client runs outside of this proces.
+                          
+      --port N             TCP/IP port to use on remote connection
+                           The default is 1954
+      --host NAME          Set DNS name or IP address to communicate on.
+                           The default is 127.0.0.1
+
+      --readline  | --no-readline
+                           Try or don't try to use Term::Readline
+      -x|--trace           Simulate line tracing (think POSIX shell set -x)
       --highlight | --no-highlight 
-                          Use or don't use ANSI terminal sequences for syntax
-                          highlight
+                           Use or don't use ANSI terminal sequences for syntax
+                           highlight
 
 =head1 DESCRIPTION
 
